@@ -5,13 +5,17 @@ use 5.008;
 use strict;
 use warnings;
 
+# OK, the following is probably paranoia. But if Perl 7 decides to
+# change this particular default I'm ready. Unless they eliminate $].
+no if $] ge '5.020', feature => qw{ signatures };
+
 use Astro::Coord::ECI;
 use Astro::Coord::ECI::Utils qw{ AU deg2rad rad2deg };
 use Carp;
 use Exporter qw{ import };
 use Test::More 0.88;	# Because of done_testing();
 
-our $VERSION = '0.001_02';
+our $VERSION = '0.002_01';
 
 our @EXPORT = qw{
     is_au_au
@@ -215,7 +219,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2019 by Thomas R. Wyant, III
+Copyright (C) 2018-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
